@@ -10,7 +10,7 @@ from .status import Status
 from . import test_case
 from .thread import Thread
 
-__version__ = '1.1.2'
+__version__ = '1.1.3'
 
 
 def judge(processor, source, tests, config=None,
@@ -36,7 +36,7 @@ def compile_source_code(container, processor, source, config):
     exec_run(container, processor.before_compile, f'{processor.workdir}/0')
     exec_result = container.exec_run(processor.compile,
                                      workdir=f'{processor.workdir}/0')
-    if 'compile' in config.get('callback', {}):
+    if 'compile' in config['callback']:
         config['callback']['compile'](exec_result.exit_code,
                                       exec_result.output)
     exec_run(container, processor.after_compile, f'{processor.workdir}/0')
@@ -45,17 +45,17 @@ def compile_source_code(container, processor, source, config):
 
 def judge_test_cases(container, processor, tests, config):
     'Judge test cases'
-    threads_limit = config.get('threads') or len(tests)
     res = []
-    for i in range(ceil(len(tests) / threads_limit)):
+    for i in range(ceil(len(tests) / config.setdefault('threads',
+                                                       len(tests)))):
         threads = []
-        for j in range(i * threads_limit,
-                       min((i + 1) * threads_limit, len(tests))):
+        for j in range(i * config['threads'],
+                       min((i + 1) * config['threads'], len(tests))):
             threads.append(
                 Thread(
                     target=test_case.__init__,
                     args=(container, processor, j + 1, tests[j], config),
-                    callback=config.get('callback', {}).get('judge')
+                    callback=config['callback'].get('judge')
                 )
             )
             threads[-1].start()
@@ -68,9 +68,10 @@ def judge_test_cases(container, processor, tests, config):
 def run(container, processor, source, tests, config=None):
     'Compile and judge'
     config = config or {}
+    config.setdefault('callback', {})
     exec_result = compile_source_code(container, processor, source, config)
     if exec_result.exit_code:
-        return [[[Status.CE, (None, None), .0]] * len(tests),
+        return [[(Status.CE, (None, None), .0)] * len(tests),
                 exec_result.output]
 
     res = judge_test_cases(container, processor, tests, config)
